@@ -45,8 +45,8 @@ def get_class(name):
     # Check if the user has specified a plugin and if the class is in there
     cfg = utils.get_project_configuration()
     if 'features' in cfg:
-        name = os.path.splitext(os.path.basename(cfg['features']))[0]
-        usermodule = imp.load_source(name, cfg['features'])
+        modname = os.path.splitext(os.path.basename(cfg['features']))[0]
+        usermodule = imp.load_source(modname, cfg['features'])
         clsmembers = inspect.getmembers(usermodule, inspect.isclass)
         for string_name, act_class in clsmembers:
             if string_name == name:
